@@ -10,8 +10,9 @@
 
 from trytond.pool import Pool
 from .cms import (
-    CMSLink, MenuItem, BannerCategory, Banner, ArticleCategory,
+    CMSLink, Menu, MenuItem, BannerCategory, Banner, ArticleCategory,
     Article, ArticleAttribute, Website, NereidStaticFile,
+    ArticleCategoryRelation,
 )
 
 
@@ -21,6 +22,7 @@ def register():
     """
     Pool.register(
         CMSLink,
+        Menu,
         MenuItem,
         BannerCategory,
         Banner,
@@ -29,5 +31,6 @@ def register():
         ArticleAttribute,
         NereidStaticFile,
         Website,
+        ArticleCategoryRelation,
         module='nereid_cms', type_='model'
     )
