@@ -103,7 +103,7 @@ class TestBanner(NereidTestCase):
             'application_user': USER,
             'default_locale': self.locale_en_us.id,
             'guest_user': guest_user,
-            'currencies': [('set', [usd.id])],
+            'currencies': [('add', [usd.id])],
         }])[0]
 
     def test_0010_banner_categ(self):
@@ -338,7 +338,7 @@ class TestGetHtml(NereidTestCase):
             'application_user': USER,
             'default_locale': self.locale_en_us.id,
             'guest_user': guest_user,
-            'currencies': [('set', [usd.id])],
+            'currencies': [('add', [usd.id])],
         }])[0]
 
     def test_0010_get_html(self):
